我希望copilot-prompt支持双语言，中文和英语。

细节如下：
1. 运行x-ipe init时，首先弹出prompt语言，默认中文，可选EN。
2. 基于选择语言，在页面上执行copilot button或者其他prompt时，能够自动显示该语言适配的prompt。
3. 在copilot-prompt.json内同时显示双语prompt
4. x-ipe upgrade --lang能够改变语言选择。